@@ -30,7 +30,7 @@ from drf_spectacular.plumbing import (
     build_examples_list, build_generic_type, build_listed_example_value, build_media_type_object,
     build_mocked_view, build_object_type, build_parameter_type, build_serializer_context, error,
     filter_supported_arguments, follow_field_source, follow_model_field_lookup, force_instance,
-    get_doc, get_list_serializer, get_type_hints, get_view_model, is_basic_serializer,
+    get_doc, get_list_serializer, get_manager, get_type_hints, get_view_model, is_basic_serializer,
     is_basic_type, is_field, is_list_serializer, is_list_serializer_customized,
     is_patched_serializer, is_serializer, is_trivial_string_variation,
     modify_media_types_for_versioning, resolve_django_path_parameter, resolve_regex_path_parameter,
@@ -561,13 +561,13 @@ class AutoSchema(ViewInspector):
             # special case handling only for _resolve_path_parameters() where neither queryset nor
             # parent is set by build_field. patch in queryset as _map_serializer_field requires it
             if not field.queryset:
-                field.queryset = model_field.related_model.objects.none()
+                field.queryset = get_manager(model_field.related_model).none()
             return self._map_serializer_field(field, direction)
         elif isinstance(field, serializers.ManyRelatedField):
             # special case handling similar to the case above. "parent.parent" on child_relation
             # is None and there is no queryset. patch in as _map_serializer_field requires one.
             if not field.child_relation.queryset:
-                field.child_relation.queryset = model_field.related_model.objects.none()
+                field.child_relation.queryset = get_manager(model_field.related_model).none()
             return self._map_serializer_field(field, direction)
         elif field and not isinstance(field, (serializers.ReadOnlyField, serializers.ModelField)):
             return self._map_serializer_field(field, direction)
@@ -627,7 +627,9 @@ class AutoSchema(ViewInspector):
         serializer_field_extension = OpenApiSerializerFieldExtension.get_match(field)
         if serializer_field_extension and not bypass_extensions:
             schema = serializer_field_extension.map_serializer_field(self, direction)
-            if serializer_field_extension.get_name():
+            if schema is None:
+                return None
+            elif serializer_field_extension.get_name():
                 component = ResolvedComponent(
                     name=serializer_field_extension.get_name(),
                     type=ResolvedComponent.SCHEMA,
@@ -653,15 +655,18 @@ class AutoSchema(ViewInspector):
         if isinstance(field, serializers.ManyRelatedField):
             schema = self._map_serializer_field(field.child_relation, direction)
             # remove hand-over initkwargs applying only to outer scope
-            schema.pop('description', None)
             schema.pop('readOnly', None)
+            if meta.get('description') == schema.get('description'):
+                schema.pop('description', None)
             return append_meta(build_array_type(schema), meta)
 
-        if isinstance(field, serializers.PrimaryKeyRelatedField):
+        if isinstance(field, (serializers.PrimaryKeyRelatedField, serializers.SlugRelatedField)):
+            # SlugRelatedField is essentially a non-pk version of PrimaryKeyRelatedField.
+            is_slug = isinstance(field, serializers.SlugRelatedField)
             # read_only fields do not have a Manager by design. go around and get field
             # from parent. also avoid calling Manager. __bool__ as it might be customized
             # to hit the database.
-            if getattr(field, 'queryset', None) is not None:
+            if getattr(field, 'queryset', None) is not None and not is_slug:
                 model_field = field.queryset.model._meta.pk
             else:
                 if isinstance(field.parent, serializers.ManyRelatedField):
@@ -672,14 +677,17 @@ class AutoSchema(ViewInspector):
                     source = field.source.split('.')
                 else:
                     warn(
-                        f'Could not derive type for under-specified PrimaryKeyRelatedField '
+                        f'Could not derive type for under-specified {field.__class__.__name__} '
                         f'"{field.field_name}". The serializer has no associated model (Meta class) '
                         f'and this particular field has no type without a model association. Consider '
                         f'changing the field or adding a Meta class. defaulting to string.'
                     )
                     return append_meta(build_basic_type(OpenApiTypes.STR), meta)
 
-                # estimates the relating model field and jumps to it's target model PK field.
+                if is_slug:
+                    source.append(field.slug_field)
+
+                # estimates the relating model field and jumps to its target model PK field.
                 # also differentiate as source can be direct (pk) or relation field (model).
                 model_field = follow_field_source(model, source)
                 if callable(model_field):
@@ -695,9 +703,6 @@ class AutoSchema(ViewInspector):
         if isinstance(field, serializers.StringRelatedField):
             return append_meta(build_basic_type(OpenApiTypes.STR), meta)
 
-        if isinstance(field, serializers.SlugRelatedField):
-            return append_meta(build_basic_type(OpenApiTypes.STR), meta)
-
         if isinstance(field, serializers.HyperlinkedIdentityField):
             return append_meta(build_basic_type(OpenApiTypes.URI), meta)
 
@@ -1126,9 +1131,9 @@ class AutoSchema(ViewInspector):
                     return view.serializer_class
                 else:
                     error(
-                        'unable to guess serializer. This is graceful '
-                        'fallback handling for APIViews. Consider using GenericAPIView as view base '
-                        'class, if view is under your control. Ignoring view for now. '
+                        'unable to guess serializer. This is graceful fallback handling for APIViews. '
+                        'Consider using GenericAPIView as view base class, if view is under your control. '
+                        'Either way you may want to add a serializer_class (or method). Ignoring view for now.'
                     )
             else:
                 error('Encountered unknown view base class. Please report this issue. Ignoring for now')
@@ -1174,6 +1179,10 @@ class AutoSchema(ViewInspector):
             if (
                 self._is_list_view(serializer)
                 and get_override(serializer, 'many') is not False
+                and (
+                    direction == 'request' or '200' <= status_code < '300'
+                    or spectacular_settings.ENABLE_LIST_MECHANICS_ON_NON_2XX
+                )
             ):
                 # contain modification to this context so "listing" is not propagated elsewhere
                 example = copy.copy(example)
@@ -1489,7 +1498,7 @@ class AutoSchema(ViewInspector):
         assert_basic_serializer(serializer)
         serializer = force_instance(serializer)
 
-        with add_trace_message(serializer.__class__.__name__):
+        with add_trace_message(serializer.__class__):
             component = ResolvedComponent(
                 name=self._get_serializer_name(serializer, direction, bypass_extensions),
                 type=ResolvedComponent.SCHEMA,
