@@ -39,7 +39,7 @@ from rest_framework.test import APIRequestFactory
 from rest_framework.utils.mediatypes import _MediaType
 from uritemplate import URITemplate
 
-from drf_spectacular.drainage import Literal, _TypedDictMeta, cache, error, warn
+from drf_spectacular.drainage import cache, error, warn
 from drf_spectacular.settings import spectacular_settings
 from drf_spectacular.types import (
     DJANGO_PATH_CONVERTER_MAPPING, OPENAPI_TYPE_MAPPING, PYTHON_TYPE_MAPPING, OpenApiTypes,
@@ -58,6 +58,23 @@ if hasattr(types, 'UnionType'):
 else:
     UNION_TYPES = (typing.Union,)
 
+LITERAL_TYPES: Tuple[Any, ...] = ()
+TYPED_DICT_META_TYPES: Tuple[Any, ...] = ()
+
+if sys.version_info >= (3, 8):
+    from typing import Literal as _PyLiteral
+    from typing import _TypedDictMeta as _PyTypedDictMeta  # type: ignore[attr-defined]
+    LITERAL_TYPES += (_PyLiteral,)
+    TYPED_DICT_META_TYPES += (_PyTypedDictMeta,)
+
+try:
+    from typing_extensions import Literal as _PxLiteral
+    from typing_extensions import _TypedDictMeta as _PxTypedDictMeta  # type: ignore[attr-defined]
+    LITERAL_TYPES += (_PxLiteral,)
+    TYPED_DICT_META_TYPES += (_PxTypedDictMeta,)
+except ImportError:
+    pass
+
 if sys.version_info >= (3, 8):
     CACHED_PROPERTY_FUNCS = (functools.cached_property, cached_property)  # type: ignore
 else:
@@ -96,7 +113,7 @@ def is_list_serializer(obj) -> bool:
 
 
 def get_list_serializer(obj):
-    return force_instance(obj) if is_list_serializer(obj) else get_class(obj)(many=True)
+    return force_instance(obj) if is_list_serializer(obj) else get_class(obj)(many=True, context=obj.context)
 
 
 def is_list_serializer_customized(obj) -> bool:
@@ -227,6 +244,16 @@ def get_openapi_type_mapping():
     }
 
 
+def get_manager(model):
+    if not hasattr(model, spectacular_settings.DEFAULT_QUERY_MANAGER):
+        error(
+            f'Failed to obtain queryset from model "{model.__name__}" because manager '
+            f'"{spectacular_settings.DEFAULT_QUERY_MANAGER}" was not found. You may '
+            f'need to change the DEFAULT_QUERY_MANAGER setting. bailing.'
+        )
+    return getattr(model, spectacular_settings.DEFAULT_QUERY_MANAGER)
+
+
 def build_generic_type():
     if spectacular_settings.GENERIC_ADDITIONAL_PROPERTIES is None:
         return {'type': 'object'}
@@ -565,7 +592,7 @@ def follow_field_source(model, path, emit_warnings=True):
                 f'consider annotating the field/property? Defaulting to "string". (Exception: {exc})'
             )
 
-    def dummy_property(obj) -> str:
+    def dummy_property(obj) -> str:  # type: ignore
         pass  # pragma: no cover
     return dummy_property
 
@@ -769,13 +796,18 @@ def load_enum_name_overrides():
             choices = [c.value for c in choices]
         normalized_choices = []
         for choice in choices:
-            if isinstance(choice, str):
+            # Allow None values in the simple values list case
+            if isinstance(choice, str) or choice is None:
                 normalized_choices.append((choice, choice))  # simple choice list
             elif isinstance(choice[1], (list, tuple)):
                 normalized_choices.extend(choice[1])  # categorized nested choices
             else:
                 normalized_choices.append(choice)  # normal 2-tuple form
-        overrides[list_hash(list(dict(normalized_choices).keys()))] = name
+
+        # Get all of choice values that should be used in the hash, blank and None values get excluded
+        # in the post-processing hook for enum overrides, so we do the same here to ensure the hashes match
+        hashable_values = [value for value, _ in normalized_choices if value not in ['', None]]
+        overrides[list_hash(hashable_values)] = name
 
     if len(spectacular_settings.ENUM_NAME_OVERRIDES) != len(overrides):
         error(
@@ -1167,7 +1199,7 @@ def _resolve_typeddict(hint):
     """resolve required fields for TypedDicts if on 3.9 or above"""
     required = None
 
-    if sys.version_info >= (3, 9):
+    if hasattr(hint, '__required_keys__'):
         required = [h for h in hint.__required_keys__]
 
     return build_object_type(
@@ -1211,7 +1243,7 @@ def resolve_type_hint(hint):
         return build_array_type(resolve_type_hint(args[0]))
     elif origin is frozenset:
         return build_array_type(resolve_type_hint(args[0]))
-    elif origin is Literal:
+    elif origin in LITERAL_TYPES:
         # Literal only works for python >= 3.8 despite typing_extensions, because it
         # behaves slightly different w.r.t. __origin__
         schema = {'enum': list(args)}
@@ -1224,7 +1256,7 @@ def resolve_type_hint(hint):
         if mixin_base_types:
             schema.update(build_basic_type(mixin_base_types[0]))
         return schema
-    elif isinstance(hint, _TypedDictMeta):
+    elif isinstance(hint, TYPED_DICT_META_TYPES):
         return _resolve_typeddict(hint)
     elif origin in UNION_TYPES:
         type_args = [arg for arg in args if arg is not type(None)]  # noqa: E721
